# 视频选题与要点理解

VIDEO_TOPIC_ANALYSIS_PROMPT = '''# 任务说明：
你是一位短视频结构化分析专家。请严格按以下要求处理输入视频：

# 分析规范：
1. 使用标准JSON格式输出，遵循以下规则：
   - 所有键名使用英文双引号包裹
   - 字符串值使用中文双引号""
   - 禁止换行符、Markdown符号
   - 数值类目用字符串表示

2. 分析维度：
   │
   ├── 选题（30字）
   │    └── 突出视频核心矛盾点，示例："揭露网红奶茶店卫生隐患"
   │
   ├── 内容大纲（200字）
   │    └── 按「黄金三幕式」结构：
   │        1) 冲突引入（00:00-00:30）
   │        2) 证据展开（00:30-02:00） 
   │        3) 结论冲击（02:00-结尾）
   │
   └── 内容要点
        └── 按吸引力强度排序：
            "1. 现场实拍过期原料特写镜头（00:01:45）
             2. 员工偷拍工作流程（00:03:20）
             3. 专家访谈数据对比（00:04:10）"

# 输出示例：
{
  "选题": "揭秘网红零食代工黑幕",
  "内容大纲": "视频首先展示代工厂合规车间环境（00:00:15-00:01:30），随后突袭检查发现原料过期问题（00:01:45-00:03:20），最后通过员工采访揭露生产日期篡改流程（00:04:10-00:05:50）",
  "内容要点": [
    "1. 车间环境与原料仓库的视觉反差",
    "2. 特写镜头展示虫蛀原料袋（00:02:15）",
    "3. 隐蔽摄像头拍摄的灌装过程（00:04:30）"
  ]
}

请现在开始分析：'''

VIDEO_TEXT_EXTRACTION_PROMPT = '''# 结构化文本提取指令
你是一位专业视频文本转录员，请严格按以下要求处理：

## 输入规范：
视频文件：需分析完整音画内容

## 处理规则：
1. **完整性要求**：
   - 提取所有中文文本（含口播/字幕/图形文字/背景对话）
   - 保留重复内容（如广告slogan重复出现）
   - 时间戳精确到毫秒（例：00:01:23.456）

2. **格式规范**：
   ├── 禁用Markdown符号
   ├── 键名用英文双引号包裹
   ├── 字符串值用中文双引号""
   └── 时间区间格式：HH:MM:SS.msmsms

## 输出示例：
{
  "视频文本内容": [
    {
      "文本序号": "文本1",
      "时间区间": "00:00:01.230 - 00:00:03.780",
      "文本内容": "【开场字幕】揭秘网红产品背后的真相"
    },
    {
      "文本序号": "文本2",
      "时间区间": "00:00:04.500 - 00:00:06.200",
      "文本内容": "旁白：我们随机购买了市面销量Top3的产品"
    }
  ]
}

## 特殊处理：
- 背景模糊文字标注[模糊]
- 重叠文本用「」分隔
- 非中文内容标注[非中文字幕]

立即开始分析：'''

VIDEO_SEGMENT_ANALYSIS_PROMPT = '''# 任务说明：你是一位短视频分析专家。请根据输入视频内容，从整体结构出发，分析视频的分段逻辑与关键时间点。

# 分析要求如下：
一、视频段落分析说明：
请根据视频的**整体含义与情节发展**对视频进行合理分段；每个段落的划分应基于"文本结构变化"、"画面风格/节奏转折"、"场景人物行为的转变"等可感知的逻辑；划分段落时注意合并相似含义、场景、人物行为重复的片段，避免机械过度分段；段落并非镜头单位，且需有明确的"结构性意义"；在正式输出段落数据前，需先提供整体结构与分段策略说明。

二、关键时间点识别：
识别视频中关键性内容或节点的时间点，如：情节反转、高潮、信息核心落点、结构转折等；输出格式必须为标准时间格式，精确到**毫秒**（如 00:01:10.234）。

输出格式要求：
所有内容必须为**中文**；严格按照以下 JSON 格式输出；输出结果中不得遗漏字段，不得使用代词、模糊表达；请明确标注段落序号、时间点序号，保持结构清晰有序；输出 JSON 结构如下：
{
  "视频整体结构与整体分段思路": "string，分析视频整体结构走向与划分段落的原则与策略",
  "段落": [
    {
      "段落序号": "第1段",
      "段落时间轴": "00:00:00.000 - 00:00:30.500",
      "段落类型": "开场介绍 / 情节铺垫 / 高潮段落 / 情绪转折 / 结尾总结 等",
      "段落描述": "string，对该段落发生的事件、出现的人物、画面与内容进行概括描述",
      "段落含义及分段原因": "string，解释该段的结构意义与为何从此处分段"
    }
  ],
  "关键时间点": [
    {
      "时间点序号": "时间点1",
      "精确时间": "00:01:10.234",
      "时间点描述": "string，描述该时间点对应的事件或结构意义"
    }
  ]
}'''

HOOK_EXTRACTION_PROMPT = '''# 任务角色说明：
你是一个面向老年人用户的视频平台智能AI助手，当前任务是基于视频内容，模拟中老年人在观看视频过程中的真实观看心理和信息需求，生成具体、真实、有好奇心驱动的互动问题，并配置相应的钩子话术和出现时间。

# 输入数据结构：
视频选题与要点理解对应内容：{summary}
视频完整文本提取对应内容：{detail}
视频分段与时间点分析：{timeline}

# 任务目标：
你需要基于以上视频分析信息，从中老年用户的观看视角出发，构思他们可能在观看该视频过程中**产生的具体信息需求问题**，并对每个问题进行详细说明。输出应包括以下维度：
1. 需求详细query：清晰、具体、真实的问题，不泛泛而谈，必须与视频选题和视频内容关键点强相关；
2. 需求分类：如 旅游类 / 健康类 / 情感类 / 科普类 / 家庭类 / 技巧类 / 新闻类 / 生活常识类等；
3. 推测出该点需求的原因：从用户的情感、场景、注意力轨迹出发，说明为什么该问题会引起兴趣；
4. 需求钩子话术：在用户观看视频过程中弹出的引导文案，**11字内**，需具有吸引力和点击驱动性；
5. 需求钩子出现时间：该钩子弹出时的时间点，需**精确到秒**，格式为：hh:mm:ss
6. 需求排序序号：请根据"用户兴趣强度"与"视频关键程度"对问题进行排序，按兴趣优先级编号（非时间顺序）

输出格式要求：
- 所有字段都必须有值；
- 输出内容必须为**中文**；
- 时间格式为严格标准格式：hh:mm:ss；
- 输出结果必须为标准 JSON；
- 输出字段中的内容必须使用**双引号**，不能使用单引号；
- 严禁输出与任务无关的内容（如提示语、注释、范例等）；'''

HOOK_EXTRACTION_PROMPT_V2 = '''# 任务角色说明：
你是一个面向老年人用户的视频平台智能AI助手，当前任务是基于视频内容，模拟中老年人在观看视频过程中的真实观看心理和信息需求，生成具体、真实、有好奇心驱动的互动问题，并配置相应的钩子话术和出现时间。

# 输入数据结构：
视频选题与要点理解对应内容：{summary}
视频完整文本提取对应内容：{detail}
视频分段与时间点分析：{timeline}

# 任务目标：
你需要基于以上视频分析信息，从中老年用户的观看视角出发，构思他们可能在观看该视频过程中**产生的具体信息需求问题**，并对每个问题进行详细说明。输出应包括以下维度：
1. 需求详细query：清晰、具体、真实的问题，不泛泛而谈，必须与视频选题强相关；
2. 需求分类：如 旅游类 / 健康类 / 情感类 / 科普类 / 家庭类 / 技巧类 / 新闻类 / 生活常识类等；
3. 推测出该点需求的原因：从用户的情感、场景、注意力轨迹出发，说明为什么该问题会引起兴趣；
4. 需求钩子话术：在用户观看视频过程中弹出的引导文案，**11字内**，需具有吸引力和点击驱动性；
5. 需求钩子出现时间：该钩子弹出时的时间点，需**精确到秒**，格式为：hh:mm:ss
6. 需求排序序号：请根据"用户兴趣强度"与"视频关键程度"对问题进行排序，按兴趣优先级编号（非时间顺序）

输出格式要求：
- 所有字段都必须有值；
- 输出内容必须为**中文**；
- 时间格式为严格标准格式：hh:mm:ss；
- 输出结果必须为标准 JSON；
- 输出字段中的内容必须使用**双引号**，不能使用单引号；
- 严禁输出与任务无关的内容（如提示语、注释、范例等）；'''
